#  openMat Python - A import and export library 
#  for the openMat database format
#
#  Copyright (C) 2012 Stefan Drechsler
#
# ##### BEGIN GPL LICENSE BLOCK #####
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General
#  Public License along with this library; if not, write to the
#  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#  Boston, MA 02110-1301 USA
#
# ##### END GPL LICENSE BLOCK #####

import xml.dom.minidom as dom

import openMat

class Acquisition(object):
    
    def __init__(self, node = None):
        if isinstance(node, dom.Node):
            self.initFromXml(node)
        else:
            self.initFromArgs()
            
    def initFromArgs(self):
        self.__location = None
        self.__institute = None
        self.__person = None
        self.__date = None
        self.__descriptions = []
        self.__url = None

    def initFromXml(self, node):
        self.__location = None
        self.__institute = None
        self.__person = None
        self.__date = None
        self.__descriptions = []
        self.__url = None
        for subnode in node.childNodes:
            if subnode.firstChild == None:
                datastrip = "None"
            else:
                datastrip = subnode.firstChild.data.strip()
            if subnode.nodeName == 'location':
                self.setLocation(datastrip)
            if subnode.nodeName == 'institute':
                self.setInstitute(datastrip)
            if subnode.nodeName == 'person':
                self.setPerson(datastrip)
            if subnode.nodeName == 'date':
                self.setDate(datastrip)
            if subnode.nodeName == 'description':
                self.addDescription(datastrip)
            if subnode.nodeName == 'url':
                self.setUrl(datastrip)
    
    def setLocation(self, inLoc):
        self.__location = inLoc

    def getLocation(self):
        if self.__location is None:
            return ''
        return self.__location

    def setInstitute(self, inInst):
        self.__institute = inInst

    def getInstitute(self):
        if self.__institute is None:
            return ''
        return self.__institute

    def setPerson(self, inPers):
        self.__person = inPers

    def getPerson(self):
        if self.__person is None:
            return ''
        return self.__person

    def setDate(self, inDate):
        self.__date = inDate

    def getDate(self):
        if self.__date is None:
            return ''
        return self.__date

    def addDescription(self, inDesc):
        if (type(inDesc).__name__ == 'Text'):
            self.__descriptions.append(inDesc)
        else:
            print('Error: description must be of Text-type')

    def getDescriptions(self):
        return self.__descriptions

    def setUrl(self, inUrl):
        self.__url = inUrl

    def getUrl(self):
        if self.__url is None:
            return ''
        return self.__url

    def getAsXml(self, tagName):
        tagAcqui = dom.Element(tagName)
        if self.__location is not None:
            tagLoc = dom.Element('location')
            text = dom.Text()
            text.data = self.__location
            tagLoc.appendChild(text)
            tagAcqui.appendChild(tagLoc)
        if self.__institute is not None:
            tagInst = dom.Element('institute')
            text = dom.Text()
            text.data = self.__institute
            tagInst.appendChild(text)
            tagAcqui.appendChild(tagInst)
        if self.__person is not None:
            tagPers = dom.Element('person')
            text = dom.Text()
            text.data = self.__person
            tagPers.appendChild(text)
            tagAcqui.appendChild(tagPers)
        if self.__date is not None:
            tagDate = dom.Element('date')
            text = dom.Text()
            text.data = self.__date
            tagDate.appendChild(text)
            tagAcqui.appendChild(tagDate)
        for description in self.__descriptions:
            tagDesc = description.getAsXml('description')
            tagAcqui.appendChild(tagDesc)
        if self.__url is not None:
            tagUrl = dom.Element('url')
            text = dom.Text()
            text.data = self.__url
            tagUrl.appendChild(text)
            tagAcqui.appendChild(tagUrl)
        return tagAcqui
