#  openMat Python - A import and export library 
#  for the openMat database format
#
#  Copyright (C) 2012 Stefan Drechsler
#
# ##### BEGIN GPL LICENSE BLOCK #####
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General
#  Public License along with this library; if not, write to the
#  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#  Boston, MA 02110-1301 USA
#
# ##### END GPL LICENSE BLOCK #####

import xml.dom.minidom as dom

class Angle(object):

    def __init__(self, valueOrNode):
        if isinstance(valueOrNode, dom.Node):
            self.initFromXml(valueOrNode)
        else:
            self.initFromArgs(valueOrNode)
    
    def initFromArgs(self, inValue):
        self.__value1 = 0.0
        self.setValue1(inValue)
        self.__value2 = None
        self.__theta = None
        self.__phi = None
        self.__wasInterpolated = None
        self.__complex = None
    
    def initFromXml(self, node):
        self.__value1 = None
        self.__value2 = None
        self.__theta = None
        self.__phi = None
        self.__wasInterpolated = None
        self.__complex = None
        if node.hasAttribute('theta'):
            self.setTheta(node.getAttribute('theta'))
        else:
            self.setTheta(None)
        if node.hasAttribute('phi'):
            self.setPhi(node.getAttribute('phi'))
        else:
            self.setPhi(None)
        if node.hasAttribute('wasInterpolated'):
            self.setInterpolated(node.getAttribute('wasInterpolated'))
        else:
            self.setInterpolated(None)
        if node.hasAttribute('complex'):
            self.setComplex(node.getAttribute('complex'))
        else:
            self.setComplex(None)
        for subnode in node.childNodes:
            if subnode.nodeName == 'value':
                if self.__value1 is None:
                    self.setValue1(subnode.firstChild.data.strip())
                else:
                    self.setValue2(subnode.firstChild.data.strip())
    
    def setValue1(self, inValue):
        self.__value1 = inValue
        
    def getValue1(self):
        if self.__value1 is None:
            return ''
        return self.__value1

    def setValue2(self, inValue):
        self.__value2 = inValue

    def getValue2(self):
        if self.__value2 is None:
            return ''
        return self.__value2

    def setTheta(self, inValue):
        self.__theta = inValue

    def getTheta(self):
        if self.__theta is None:
            return ''
        return self.__theta

    def setPhi(self, inValue):
        self.__phi= inValue
        
    def getPhi(self):
        if self.__phi is None:
            return ''
        return self.__phi

    def setInterpolated(self, inBool):
        self.__wasInterpolated = inBool
        
    def getInterpolated(self):
        if self.__wasInterpolated is None:
            return ''
        return self.__wasInterpolated

    def setComplex(self, inBool):
        self.__complex= inBool
        
    def getComplex(self):
        if self.__complex is None:
            return ''
        return self.__complex

    def getAsXml(self, tagName):
        tagAngl = dom.Element(tagName)
        if self.__theta is not None:
            tagAngl.setAttribute('theta', self.__theta)
        if self.__phi is not None:
            tagAngl.setAttribute('phi', self.__phi )
        if self.__wasInterpolated is not None:
            if self.__wasInterpolated:
                tagAngl.setAttribute('wasInterpolated', 'true')
            else:
                tagAngl.setAttribute('wasInterpolated', 'false')
        if self.__complex is not None:
            if self.__complex:
                tagAngl.setAttribute('complex', 'true')
            else:
                tagAngl.setAttribute('complex', 'false')
        if self.__value1 is not None:
            tagVal = dom.Element('value')
            text = dom.Text()
            text.data = self.__value1
            tagVal.appendChild(text)
            tagAngl.appendChild(tagVal)
        if self.__value2 is not None:
            tagVal = dom.Element('value')
            text = dom.Text()
            text.data = self.__value2
            tagVal.appendChild(text)
            tagAngl.appendChild(tagVal)
        return tagAngl
