#  openMat Python - A import and export library 
#  for the openMat database format
#
#  Copyright (C) 2012 Stefan Drechsler
#
# ##### BEGIN GPL LICENSE BLOCK #####
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General
#  Public License along with this library; if not, write to the
#  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#  Boston, MA 02110-1301 USA
#
# ##### END GPL LICENSE BLOCK #####

import xml.dom.minidom as dom

import openMat.DistanceBD

class DataBD(object):
    
    def __init__(self, acquiOrNode, inMethod = None):
        if isinstance(acquiOrNode, dom.Node):
            self.initFromXml(acquiOrNode)
        else:
            self.initFromArgs(acquiOrNode, inMethod)
    
    def initFromArgs(self, inAcqui, inMethod):
        self.__acquisition = None
        self.setAcquisition(inAcqui)
        self.__distanceBD = []
        self.__method = inMethod

    def initFromXml(self, node):
        self.__acquisition = None
        self.__distanceBD = []
        self.__method = None
        if node.hasAttribute('method'):
            self.setMethod(node.getAttribute('method'))
        else:
            print('Error: Data method attribute is missing.')
        for subnode in node.childNodes:
            if subnode.nodeName == 'acquisition':
                self.setAcquisition(openMat.Acquisition.Acquisition(subnode))
            if subnode.nodeName == 'distance':
                self.addDistance(openMat.DistanceBD.DistanceBD(subnode))

    def getMethod(self):
        return self.__method

    def setMethod(self, inMeth):
        self.__method = inMeth

    def setAcquisition(self, inAcqui):
        if (type(inAcqui).__name__ == 'Acquisition'):
            self.__acquisition = inAcqui
        else:
            print('Error: acquisition must be of Acquisition-type')

    def getAcquisition(self):
        return self.__acquisition

    def addDistance(self, inDist):
        if (type(inDist).__name__ == 'DistanceBD'):
            self.__distanceBD.append(inDist)
        else:
            print('Error: distance must be of Distance-type')

    def getDistances(self):
        return self.__distanceBD

    def getAsXml(self, tagName):
        tagData = dom.Element(tagName)
        methodStr = "{0:-d}".format(self.__method)
        tagData.setAttribute('method', methodStr)
        tagAcqui = self.__acquisition.getAsXml('acquisition')
        tagData.appendChild(tagAcqui)
        for distance in self.__distanceBD:
            tagDist = distance.getAsXml('distance')
            tagData.appendChild(tagDist)
        return tagData

