#  openMat Python - A import and export library 
#  for the openMat database format
#
#  Copyright (C) 2012 Stefan Drechsler
#
# ##### BEGIN GPL LICENSE BLOCK #####
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General
#  Public License along with this library; if not, write to the
#  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#  Boston, MA 02110-1301 USA
#
# ##### END GPL LICENSE BLOCK #####


import xml.dom.minidom as dom

import openMat.FrequencyBD

class DistanceBD(object):
    
    def __init__(self, frequOrNode):
        if isinstance(frequOrNode, dom.Node):
            self.initFromXml(frequOrNode)
        else:
            self.initFromArgs(frequOrNode)
    
    def initFromArgs(self, frequ):
        self.__frequencies = []
        self.addFrequence(frequ)
        self.__dAtt = None

    def initFromXml(self, node):
        self.__frequencies = []
        if node.hasAttribute('d'):
            self.setD(node.getAttribute('d'))
        else:
            self.setD(None)
        for subnode in node.childNodes:
            if subnode.nodeName == 'frequency':
                self.addFrequence(openMat.FrequencyBD.FrequencyBD(subnode))

    def addFrequence(self, freq):
        if (type(freq).__name__ == 'FrequencyBD'):
            self.__frequencies.append(freq)
        else:
            print('Error: frequency must be of FrequencyBD-type')

    def getFrequencies(self):
        return self.__frequencies

    def setD(self, inD):
        self.__dAtt = inD
        
    def getD(self):
        if self.__dAtt is None:
            return ''
        return self.__dAtt
        
    def getAsXml(self, tagName):
        tagDist = dom.Element(tagName)
        if self.__dAtt is not None:
            tagDist.setAttribute('d', self.__dAtt)
        for freq in self.__frequencies:
            tagFreq = freq.getAsXml('frequency')
            tagDist.appendChild(tagFreq)
        return tagDist
