#  openMat Python - A import and export library 
#  for the openMat database format
#
#  Copyright (C) 2012 Stefan Drechsler
#
# ##### BEGIN GPL LICENSE BLOCK #####
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General
#  Public License along with this library; if not, write to the
#  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#  Boston, MA 02110-1301 USA
#
# ##### END GPL LICENSE BLOCK #####

import xml.dom.minidom as dom

import openMat.AngleBD

class FrequencyBD(object):
    
    def __init__(self, angleOrNode, freq = None):
        if isinstance(angleOrNode, dom.Node):
            self.initFromXml(angleOrNode)
        else:
            self.initFromArgs(angleOrNode, freq)
    
    def initFromArgs(self, inAngle, freq):
        self.__angles = []
        self.__fAtt = freq
        self.addAngle(inAngle)

    def initFromXml(self, node):
        self.__angles = []
        if node.hasAttribute('f'):
            self.setFreq(node.getAttribute('f'))
        else:
            print('Error: Frequency f attribute is missing.')
        for subnode in node.childNodes:
            if subnode.nodeName == 'angle':
                self.addAngle(openMat.AngleBD.AngleBD(subnode))

    def addAngle(self, inAngle):
        if (type(inAngle).__name__ == 'AngleBD'):
            self.__angles.append(inAngle)
        else:
            print('Error: angle must be of AngleBD-type')

    def getAngles(self):
        return self.__angles

    def setFreq(self, inFreq):
        self.__fAtt = inFreq

    def getFreq(self):
        return self.__fAtt

    def getAsXml(self, tagName):
        tagFreq = dom.Element(tagName)
        fStr = "{0:-0.1f}".format(self.__fAtt)
        tagFreq.setAttribute('f', fStr)
        for angle in self.__angles:
            tagAngl = angle.getAsXml('angle')
            tagFreq.appendChild(tagAngl)
        return tagFreq
