#  openMat Python - A import and export library 
#  for the openMat database format
#
#  Copyright (C) 2012 Stefan Drechsler
#
# ##### BEGIN GPL LICENSE BLOCK #####
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General
#  Public License along with this library; if not, write to the
#  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#  Boston, MA 02110-1301 USA
#
# ##### END GPL LICENSE BLOCK #####

import xml.dom.minidom as dom

import openMat.Text
import openMat.Data
import openMat.DataBD
import openMat.Texture
import openMat.File
import openMat.Price

types = ['object', 'mat']

class Material(object):

    def __init__(self, nameOrNode, description = None, absType = None):
        #if (type(nameOrNode).__name__ == 'Node'):
        if isinstance(nameOrNode, dom.Node):
            self.initFromXml(nameOrNode)
        else:
            self.initFromArgs(nameOrNode, description, absType)
    
    def initFromArgs(self, name, description, absType):
        self.__typeAtt = 'mat'
        self.setType(absType)
        self.__names = []
        self.addName(name)
        self.__descriptions = []
        self.addDescription(description)
        self.__diffData = None
        self.__scatData = None
        self.__absoData = None
        self.__reflData = None
        self.__bdtfData = None
        self.__url = None
        self.__sampleImage = None
        self.__cadModel = None
        self.__textures = []
        self.__files = []
        self.__price = None
    
    def initFromXml(self, node):
        self.__names = []
        self.__descriptions = []
        self.__textures = []
        self.__files = []
        self.__diffData = None
        self.__scatData = None
        self.__absoData = None
        self.__reflData = None
        self.__bdtfData = None
        self.__url = None
        self.__sampleImage = None
        self.__cadModel = None
        self.__price = None
        if node.hasAttribute('type'):
            self.setType(node.getAttribute('type'))
        else:
            print('Error: Material type Attribute is missing.')
        
        for subnode in node.childNodes:
            if subnode.nodeName == 'name':
                self.addName(openMat.Text.Text(subnode))
            if subnode.nodeName == 'description':
                self.addDescription(openMat.Text.Text(subnode))
            if subnode.nodeName == 'diffData':
                self.setDiffData(openMat.Data.Data(subnode))
            if subnode.nodeName == 'scatData':
                self.setScatData(openMat.Data.Data(subnode))
            if subnode.nodeName == 'absoData':
                self.setAbsoData(openMat.Data.Data(subnode))
            if subnode.nodeName == 'impeData':
                self.setReflData(openMat.Data.Data(subnode))
            if subnode.nodeName == 'BDTFData':
                self.setBdtfData(openMat.DataBD.DataBD(subnode))
            if subnode.nodeName == 'url':
                self.setUrl(subnode.firstChild.data.strip())
            if subnode.nodeName == 'sampleImage':
                self.setSampleImage(subnode.firstChild.data.strip())
            if subnode.nodeName == 'cadModel':
                self.setCadModel(subnode.firstChild.data.strip())
            if subnode.nodeName == 'texture':
                self.addTexture(openMat.Texture.Texture(subnode))
            if subnode.nodeName == 'additionalfile':
                self.addFile(openMat.File.File(subnode))
            if subnode.nodeName == 'price':
                self.setPrice(openMat.Price.Price(subnode))
    
    def setType(self, inType):
        if (types.__contains__(inType)):
            self.__typeAtt = inType
        else:
            print('Error: Material type is not valid.')
    
    def getType(self):
        return self.__typeAtt
    
    def addName(self, inName):
        if (type(inName).__name__ == 'Text'):
            self.__names.append(inName)
        else:
            print('Error: Name must be of Text-type.')
        
    def getNames(self):
        return self.__names;    
        
    def addDescription(self, inDescription):
        if (type(inDescription).__name__ == 'Text'):
            self.__descriptions.append(inDescription)
        else:
            print('Error: Description must be of Text-type.')

    def getDescriptions(self):
        return self.__descriptions;    
        
    def setDiffData(self, data):
        if (type(data).__name__ == 'Data'):
            self.__diffData = data
        else:
            print('Error: DiffData must be of Data-type.')
        
    def getDiffData(self):
        return self.__diffData
        
    def setScatData(self, data):
        if (type(data).__name__ == 'Data'):
            self.__scatData = data
        else:
            print('Error: ScatData must be of Data-type.')

    def getScatData(self):
        return self.__scatData
        
    def setAbsoData(self, data):
        if (type(data).__name__ == 'Data'):
            self.__absoData = data
        else:
            print('Error: AbsoData must be of Data-type.')

    def getAbsoData(self):
        return self.__absoData

    def setReflData(self, data):
        if (type(data).__name__ == 'Data'):
            self.__reflData = data
        else:
            print('Error: ReflData must be of Data-type.')

    def getReflData(self):
        return self.__reflData

    def setBdtfData(self, data):
        if (type(data).__name__ == 'DataBD'):
            self.__bdtfData = data
        else:
            print('Error: BdtfData must be of DataBD-type.')

    def getBdtfData(self):
        return self.__bdtfData

    def setUrl(self, inUrl):
        self.__url = inUrl

    def getUrl(self):
        if self.__url is None:
            return ''
        return self.__url

    def setSampleImage(self, inImage):
        self.__sampleImage = inImage

    def getSampleImage(self):
        if self.__sampleImage is None:
            return ''
        return self.__sampleImage

    def setCadModel(self, inModel):
        self.__cadModel = inModel

    def getCadModel(self):
        if self.__cadModel is None:
            return ''
        return self.__cadModel

    def addTexture(self, texture):
        if (type(texture).__name__ == 'Texture'):
            self.__textures.append(texture)
        else:
            print('Error: textures must be of Texture-type.')

    def getTextures(self):
        return self.__textures

    def addFile(self, file):
        if (type(file).__name__ == 'File'):
            self.__files.append(file)
        else:
            print('Error: file must be of File-type.')

    def getFiles(self):
        return self.__files

    def setPrice(self, inPrice):
        if (type(inPrice).__name__ == 'Price'):
            self.__price = inPrice
        else:
            print('Error: price must be of Price-type.')

    def getPrice(self):
        return self.__price

    def getAsXml(self):
        tagMaterial = dom.Element('material')
        tagMaterial.setAttribute('type', self.__typeAtt)
        for name in self.__names:
            tagName = name.getAsXml('name')
            tagMaterial.appendChild(tagName)
        for description in self.__descriptions:
            tagDesc = description.getAsXml('description')
            tagMaterial.appendChild(tagDesc)
        if self.__diffData is not None:
            tagDiff = self.__diffData.getAsXml('diffData')
            tagMaterial.appendChild(tagDiff)
        if self.__scatData is not None:
            tagScat = self.__scatData.getAsXml('scatData')
            tagMaterial.appendChild(tagScat)
        if self.__absoData is not None:
            tagAbso = self.__absoData.getAsXml('absoData')
            tagMaterial.appendChild(tagAbso)
        if self.__reflData is not None:
            tagRefl = self.__reflData.getAsXml('impeData')
            tagMaterial.appendChild(tagRefl)
        if self.__bdtfData is not None:
            tagBdtf = self.__bdtfData.getAsXml('BDTFData')
            tagMaterial.appendChild(tagBdtf)
        if self.__url is not None:
            tagUrl = dom.Element('url')
            text = dom.Text()
            text.data = self.__url
            tagUrl.appendChild(text)
            tagMaterial.appendChild(tagUrl)
        if self.__sampleImage is not None:
            tagProbeImage = dom.Element('sampleImage')
            text = dom.Text()
            text.data = self.__sampleImage
            tagProbeImage.appendChild(text)
            tagMaterial.appendChild(tagProbeImage)
        if self.__cadModel is not None:
            tagCadModel = dom.Element('cadModel')
            text = dom.Text()
            text.data = self.__cadModel
            tagCadModel.appendChild(text)
            tagMaterial.appendChild(tagCadModel)
        for texture in self.__textures:
            tagTexture = texture.getAsXml('texture')
            tagMaterial.appendChild(tagTexture)
        for additionalFile in self.__files:
            tagFile = additionalFile.getAsXml('additionalfile')
            tagMaterial.appendChild(tagFile)
        if self.__price is not None:
            tagPrice = self.__price.getAsXml('price')
            tagMaterial.appendChild(tagPrice)
        return tagMaterial