#  openMat Python - A import and export library 
#  for the openMat database format
#
#  Copyright (C) 2012 Stefan Drechsler
#
# ##### BEGIN GPL LICENSE BLOCK #####
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General
#  Public License along with this library; if not, write to the
#  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#  Boston, MA 02110-1301 USA
#
# ##### END GPL LICENSE BLOCK #####

import xml.dom.minidom as dom

import openMat.Material

class MaterialDatabase(object):
    
    def __init__(self):
        self.__materials = []
    
    def add(self, material):
        if (type(material).__name__ == 'Material'):
            self.__materials.append(material)
        else:
            print('Error: Name must be of Material-type')

    def getItem(self, index):
        return self.__materials[index]
    
    def length(self):
        return len(self.__materials)
        
    def writeXML(self, file):
        baum = dom.Document()
        tagDatabase = dom.Element('material_database')
        tagDatabase.setAttribute('xmlns', 'http://www.hcu-hamburg.de')
        tagDatabase.setAttribute('xmlns:xsi', 'http://www.w3.org/2001/XMLSchema-instance')
        tagDatabase.setAttribute('xsi:schemaLocation', 'http://www.hcu-hamburg.de MaterialDatabase.xsd')
        
        for material in self.__materials:
            tagMaterial = material.getAsXml()
            tagDatabase.appendChild(tagMaterial)
        
        baum.appendChild(tagDatabase)
        with open(file, "w") as f:
            baum.writexml(f, '  ', '  ', '\n', 'UTF-8')

    def readXML(self, file):
        baum = dom.parse(file)
        for element in baum.firstChild.childNodes:
            if element.nodeName == 'material':
                mat = openMat.Material.Material(element)
                self.add(mat)
            