#  openMat Python - A import and export library 
#  for the openMat database format
#
#  Copyright (C) 2012 Stefan Drechsler
#
# ##### BEGIN GPL LICENSE BLOCK #####
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General
#  Public License along with this library; if not, write to the
#  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#  Boston, MA 02110-1301 USA
#
# ##### END GPL LICENSE BLOCK #####

import xml.dom.minidom as dom

currencies = ['EUR', 'USD', 'NOK']

class Price(object):
    
    def __init__(self, currOrNode, inDate = None, inSource = None):
        if isinstance(currOrNode, dom.Node):
            self.initFromXml(currOrNode)
        else:
            self.initFromArgs(currOrNode, inDate, inSource)
            
    def initFromArgs(self, inCurr, inDate, inSource):
        self.__value = None
        self.__currency = None
        self.__date = None
        self.__source = None
        self.setCurrency(inCurr)
        self.setDate(inDate)
        self.setSource(inSource)

    def initFromXml(self, node):
        if node.hasAttribute('currency'):
            self.setCurrency(node.getAttribute('currency'))
        else:
            print('Error: Price currency attribute is missing.')
        if node.hasAttribute('date'):
            self.setDate(node.getAttribute('date'))
        else:
            print('Error: Price date attribute is missing.')
        if node.hasAttribute('source'):
            self.setSource(node.getAttribute('source'))
        else:
            print('Error: Price source attribute is missing.')
        self.setValue(node.firstChild.data.strip())
    
    def setCurrency(self, inCurr):
        if (currencies.__contains__(inCurr)):
            self.__currency = inCurr

    def getCurrency(self):
        return self.__currency

    def setDate(self, text):
        self.__date = text

    def getDate(self):
        return self.__date

    def setSource(self, text):
        self.__source = text

    def getSource(self):
        return self.__source

    def setValue(self, val):
        self.__value = val

    def getValue(self):
        return self.__value

    def getAsXml(self, tagName):
        tagPric = dom.Element(tagName)
        tagPric.setAttribute('currency', self.__currency)
        tagPric.setAttribute('date', self.__date)
        tagPric.setAttribute('source', self.__source)
        text = dom.Text()
        text.data = self.__value
        tagPric.appendChild(text)
        return tagPric

