#  openMat Python - A import and export library 
#  for the openMat database format
#
#  Copyright (C) 2012 Stefan Drechsler
#
# ##### BEGIN GPL LICENSE BLOCK #####
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General
#  Public License along with this library; if not, write to the
#  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#  Boston, MA 02110-1301 USA
#
# ##### END GPL LICENSE BLOCK #####


import xml.dom.minidom as dom

languages = ['en', 'da', 'de', 'es', 'fi', 'fr', 'it', 'nl', 'no', 'sv', 'pt', 'nl']

class Text(object):

    def __init__(self, nameOrNode = None):
        if isinstance(nameOrNode, dom.Node):
            self.initFromXml(nameOrNode)
        else:
            self.initFromArgs(nameOrNode)

        
    def initFromArgs(self, name):
        self.__content = name
        self.__language = None
    
    def initFromXml(self, node):
        self.__content = None
        self.__language = None
        if node.hasAttribute('lang'):
            self.setLanguage(node.getAttribute('lang'))
        if node.firstChild == None:
            datastrip = "None"
        else:
            datastrip = node.firstChild.data.strip()
    
        self.setContent(datastrip)
    
    def setLanguage(self, lan):
        if (languages.__contains__(lan)):
            self.__language = lan
        else:
            print('Error: lang-attribute is not valid.')

    def getLanguage(self):
        if (self.__language is None):
            return "None"
        return self.__language

    def setContent(self, text):
        self.__content = text
        
    def getContent(self):
        return self.__content        
        
    def getAsXml(self, tagName):
        tagText = dom.Element(tagName)
        if self.__language is not None:
            if self.__language != '':
                tagText.setAttribute('lang', self.__language)
        text = dom.Text()
        text.data = self.__content
        tagText.appendChild(text)
        return tagText


       
