#  openMat Python - A import and export library 
#  for the openMat database format
#
#  Copyright (C) 2012 Stefan Drechsler
#
# ##### BEGIN GPL LICENSE BLOCK #####
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 3 of the License, or (at your option) any later version.
#
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General
#  Public License along with this library; if not, write to the
#  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
#  Boston, MA 02110-1301 USA
#
# ##### END GPL LICENSE BLOCK #####

import xml.dom.minidom as dom

class Texture(object):

    def __init__(self, node):
        if isinstance(node, dom.Node):
            self.initFromXml(node)
        else:
            self.initFromArgs()
            
    def initFromArgs(self):
        self.__color = None
        self.__content = None

    def initFromXml(self, node):
        if node.hasAttribute('color'):
            self.setColor(node.getAttribute('color'))
        else:
            self.setColor(None)
        self.setContent(node.firstChild.data.strip())
    
    def setContent(self, text):
        self.__content = text

    def getContent(self):
        return self.__content
    
    def setColor(self, col):
        self.__color = col

    def getColor(self):
        return self.__color

    def getAsXml(self, tagName):
        tagText = dom.Element(tagName)
        if self.__color is not None:
            tagText.setAttribute('color', self.__color)
        text = dom.Text()
        text.data = self.__content
        tagText.appendChild(text)
        return tagText

